@@ -13,10 +13,7 @@ BEGIN {
 }
 
 sub import {
-	my ($caller, $pkg, @types) = (scalar caller, @_);
-	if (@types) {	
-		Coerce::Types::Standard->import::into($caller, @types)
-	}
+	my ($caller) = (scalar caller);
 	$PRO{keyword}($caller, 'chain', sub {
 		my ($name, @factory) = @_;
 		my ($meta, $chain, $exists) = (Rope->get_meta($caller), [], 0);
@@ -34,7 +31,6 @@ sub import {
 		if (!$exists) {
 			$caller->property($name,
 				value => $cb,
-				enumerable => 1
 			);
 		} else {
 			$caller->after($name, $cb);
@@ -52,7 +48,7 @@ Rope::Type - Rope chained properties
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =cut
 
